# flask-heroku-cacheify

Automatic Flask cache configuration on Heroku.

![Thinking Man Sketch](https://raw.github.com/rdegges/flask-heroku-cacheify/master/assets/thinking-man-sketch.jpg)


## Purpose

Configuring your cache on Heroku can be a time sink.  There are lots of
different caching addons available on Heroku (Redis, Memcached, etc.), and among
those -- lots of competitors.

`flask-heroku-cacheify` makes your life easy by automatically configuring your
Flask application to work with whatever caching addons you've got provisioned
on Heroku, allowing you to easily swap out addon providers at will, without any
trouble.

Instead of looking through documentation, testing stuff out, etc.,
`flask-heroku-cacheify` will just do everything for you :)


## Install

To install `flask-heroku-cacheify`, use [pip](http://pip.readthedocs.org/en/latest/).

```bash
$ pip install flask-heroku-cacheify
```


## Usage

TODO


## Changelog

v0.9: 04-18-2013

    - First *real* release! Supports MemCachier and RedisGreen!

v0.8: 04-18-2013

    - Pushing eigth release to PyPI (don't use this still!).

v0.7: 04-18-2013

    - Pushing seventh release to PyPI (don't use this still!).

v0.6: 04-18-2013

    - Pushing sixth release to PyPI (don't use this still!).

v0.5: 04-18-2013

    - Pushing fifth release to PyPI (don't use this still!).

v0.4: 04-18-2013

    - Pushing fourth release to PyPI (don't use this still!).

v0.3: 04-18-2013

    - Pushing third release to PyPI (don't use this still!).

v0.2: 04-18-2013

    - Pushing second release to PyPI (don't use this still!).

v0.1: 04-18-2013

    - Pushing first release to PyPI (don't use this yet!).

v0.0: 04-14-2013

    - Started work >:)
